@@ -70,7 +70,7 @@ class TestGbpConfigCommand(unittest.TestCase):
         self.assertEqual(ret, 0)
 
     def test_print_cmd_single_value_override(self):
-        """Can we fetch a single configuration value that is overriden by config"""
+        """Can we fetch a single configuration value that is overridden by config"""
         printstub = self.SingleValuePrintStub()
         query = 'config.color-scheme'
         ret = gbp.scripts.config.print_cmd_values(query, printstub)
@@ -79,23 +79,23 @@ class TestGbpConfigCommand(unittest.TestCase):
 
     def test_print_cmd_all_values(self):
         """Can we fetch the configuration for all commands"""
-        for cmd in [ 'buildpackage',
-                     'clone',
-                     'config',
-                     'create_remote_repo',
-                     'dch',
-                     'import_dsc',
-                     'import_orig',
-                     'pq',
-                     'pull' ]:
+        for cmd in ['buildpackage',
+                    'clone',
+                    'config',
+                    'create_remote_repo',
+                    'dch',
+                    'import_dsc',
+                    'import_orig',
+                    'pq',
+                    'pull']:
             printstub = self.AllValuesPrintStub(cmd)
             ret = gbp.scripts.config.print_cmd_values(cmd, printstub)
             self.assertIn('%s.color' % cmd, printstub.result.keys())
             self.assertEquals(printstub.result['%s.color' % cmd], 'auto')
             self.assertEqual(ret, 0)
 
-    def test_unexistent_cmds(self):
-        """Unexisting commands should print no values"""
+    def test_nonexistent_cmds(self):
+        """Non-existing commands should print no values"""
         for cmd in ["import_dscs", "supercommand"]:
             printstub = self.AllValuesPrintStub(cmd)
             ret = gbp.scripts.config.print_cmd_values(cmd, printstub)
